function [h,t,p,ws,wd,u,v,i,k,FT2]=TROPOPAUSE(T,Z,P,WS,WD,U,V)
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

% Purpose:
% This is a Matlab function to calculate tropopause height and other characters at tropopause height using the WMO
% thermal tropopause definition given a temperature, geopotential
% height and pressure, with referencs of Cameron R. Homeyer IDL
% tropopause code
%
%  		
%  Inputs:
% 		T      : Given temperature column. Expected in K
% 		Z      : Given height column. Expected in meters.
% 		P      : Given pressure column. Expected in hPa. 
%              WS      : Given wind speed column. Expected in m/s. 
%              WD      : Given wind speed column. Expected in m/s. 
%              U       : Given zonal wind speed column. Expected in m/s. 
%              V       : Given meridional wind speed column. Expected in m/s. 
%  Key notes   : The default vertical resolution of inputs variables
%                is 20m.Before calling this function, the radiosonde data have to be
%                interpreted to 20m vertical resolution.
%
%  Output:
% 		h      : Tropopause height in meters.
% 		t      : Tropopause temperature in k.
% 		p      : Tropopause pressure in hPa.
% 		ws     : Wind speed at tropopause height in m/s.
% 		wd     : Wind direction at tropopause height in degree.
%               u      : Zonal wind speed at tropopause height in m/s.
%               v      : Meridional wind speed at tropopause height in m/s.
%               i      : Row of tropopause indexk: row of index for next tropopause 
%               FT2    : logical value whether to compute next tropopause,0 value
%                        will not compute the next tropopause,1 value is on the contrary.
%
%  Author and history:
% 		Xuelong Chen  2010-4-20.
%
%  Key notes on how to call this function:
%       FT2=1;   % give the first logical value of FT2
%       tpn=1;   
%       while FT2==1
%             [height,tem,p1,ws1,wd1,u1,v1,i,s,FT2]=TROPOPAUSE(T,Z,P,WS,WD,U,V);
%             h(tpn,z)=height;        t(tpn,z)=tem; p(tpn,z)=p1;
%             ws(tpn,z)=ws1;          u(tpn,z)=u1;
%             v(tpn,z)=v1;   
%             tpn=tpn+1;
%       end

% Referee:
% Chen,X.L., Ma,Y.M., Kelder,H., Su,Z., and Yang,K.: On the behaviour of the tropopause folding events over the Tibetan Plateau, Atmos. Chem. Phys. Discuss., 10, 22993-23016, doi:10.5194/acpd-10-22993-2010, 2010
% Homeyer, Cameron R., Kenneth P. Bowman, and Laura L. Pan (2010), Extratropical tropopause transition layer characteristics from high-resolution sounding data, J Geophys Res, 115, D13108

FT2=0;  % give the next tropopause exist logical value, 
h=NaN;t=NaN;p=NaN;i=NaN;k=NaN;
ws=NaN;wd=NaN;u=NaN;v=NaN;
for i=1:length(T)-100   
      if (T(i)-T(i+1))/20 <=0.002      %judge start condition to compute tropopause 
           lapse=NaN;
           for s=1:100                 %compute lapse rate between start layer and each layer above it in 2km                            
               lapse(s)=(T(i)-T(i+s))/(20*s);
           end 
           rr=lapse>0.002;             %numb of lapse rate>0.002
           if sum(rr)==0               
                                       %output tropopause pressure, height, wind etc information
              h=Z(i);  
              t=T(i);p=P(i);
              ws=WS(i); u=U(i);v=V(i);
              wd=WD(i);
              for k=i:length(T)-50     %judge the condition for next tropopause
                  lapse=NaN;
                  for s=1:50           %vertical resolution is 20m,so compute 1km lapse rate (50 layers)                      
                     lapse(s)=(T(k)-T(s+k))/(20*s);
                  end
                  rr=lapse>0.003;      %numb of lapse rate>0.003
                  if  sum(rr)==50                             
                      FT2=1;           %true condition to compute the next tropopause
                      break;
                  end
              end             
              break;
           end
       end
end
    